---
title: Step
---

# Step

This section provides description for the `Step` class. Each `Step` uses its own set of Methods and Datasets and implements the logic necessary to read a set of inputs, perform the transformation and write the outputs. All steps are available through the command line interface when running the `gentropy` command.
